Nxpy File_object
================

You can install the library with pip::

    pip install nxpy-file-object

*Nxpy File_object* provides base classes to simplify the implementation of file-like objects that
delegate their implementation to a file object attribute.

The library's documentation is available on
`ReadTheDocs <https://nxpy.readthedocs.io/en/latest/file_object.html>`_.
